==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/zh-CN/general.php <==
<?php

    return [
    'accessories'			=> '附属品',
    'activated'			    => '已激活',
    'accessory'				=> '附属品',
    'accessory_report'		=> '配件报告',
    'action'                => '操作',
    'activity_report'		=> '活动报告',
    'address'				=> '地址',
    'admin'					=> '管理员',
    'administrator'			=> '管理员',
    'add_seats'             => '已增加空位',
    'all_assets'			=> '所有资产',
    'all'       			=> '所有',
    'archived'              => '已存档',
    'asset_models'			=> '资产型号',
    'asset_model'			=> '模型',
    'asset'					=> '资产',
    'asset_report'          => '资产报备',
    'asset_tag'				=> '资产标签',
    'assets_available'		=> '可用资产',
    'audit'				    => '审计',
    'audit_report'			=> '审核日志',
    'assets'				=> '资产',
    'avatar_delete'         => '删除头像',
    'avatar_upload'         => '上传头像',
    'back'      			=> '后退',
    'bad_data'      		=> '未发现任何东西，是否数据错误？',
    'bulkaudit'             => '批量审核',
    'bulkaudit_status'      => '盘点状态',
    'bulk_checkout'  		=> '批量借出',
    'bystatus'              => '按状态',
    'cancel'  				=> '取消',
    'categories'			=> '目录',
    'category'				=> '类别：',
    'change' 		        => '归还/借出',
    'changeemail'  			=> '更改邮箱',
    'changepassword'  		=> '修改密码',
    'checkin'  				=> '归还',
    'checkin_from'  		=> '输入来源',
    'checkout'  			=> '借出',
    'checkouts_count'       => '签出',
    'checkins_count'        => '签入',
    'user_requests_count'   => '请求',
    'city'  				=> '城市',
	'click_here'			=> '点击此处',
    'clear_selection'		=> '清除选择',
    'companies'			    => '公司',
    'company'				=> '公司',
    'component'			    => '组件',
    'components'			=> '组件',
	'complete'				=> '完成',
    'consumable'			=> '消耗品',
    'consumables'			=> '消耗品',
    'country'  				=> '国家',
    'create'				=> '新增',
    'created'               => '项目已创建',
    'created_asset'			=> '新建资产',
    'created_at' 			=> '创建于',
    'record_created' 		=> '记录已创建',
    'updated_at' 			=> '更新日期',
    'currency'  			=> 'RMB', // this is deprecated
    'current'  				=> '当前',
    'custom_report'         => '自定义资产报表',
    'dashboard'				=> '控制面板',
    'days'      			=> '天数',
    'days_to_next_audit'    => '距离下一次盘点的天数',
    'date'					=> '日期',
    'debug_warning'         => '警告!',
    'debug_warning_text'    => '此应用程序运行在生产模式下的调试状态。如果您的应用程序可以被外部访问，这会使敏感数据暴露。通过将 <code>.env</code> 文件中的<code>APP_DEBUG</code> 值设置为 <code>false</code>来 禁用调试模式。',
    'delete'  				=> '刪除',
    'delete_confirm'  		=> '是否确定删除此项',
    'deleted'  				=> '已删除',
    'delete_seats'  		=> '已移除空位',
    'departments'           => '部门',
    'department'           => '部门',
    'deployed'				=> '已分配',
    'depreciation_report'	=> '折旧报告',
    'details'               => '详细信息',
    'download'				=> '下载',
    'download_all'				=> '下载全部',
    'depreciation'			=> '折旧',
    'editprofile'  			=> '修改简介',
    'eol'					=> '寿命',
    'email_domain'			=> '邮件域',
    'email_format'			=> '电子邮件格式',
    'email_domain_help'		=> '这在导入时用以生成电子邮件地址',
    'filastname_format'			=> '缩写名 姓，例如(jsmith@example.com)',
    'firstname_lastname_format'	=> '名 姓，例如 (jane.smith@example.com)',
    'firstname_lastname_underscore_format' => '名 姓，例如(jane_smith@example.com)',
    'lastnamefirstinitial_format' =>  '姓氏首字母（smithj@example.com）',
    'firstintial_dot_lastname_format' => '缩写名 姓，例如(jsmith@example.com)',
    'first'					=> '首页',
    'firstnamelastname'     => '名 姓，例如 (jane.smith@example.com)',
    'lastname_firstinitial' => '姓 缩写名, 例如 (smith_j@example.com)',
    'firstinitial.lastname' => '缩写名 姓，例如(jsmith@example.com)',
    'firstnamelastinitial'  => '名 姓，例如 (jane.smith@example.com)',
    'first_name'			=> '名字',
    'first_name_format'		=> '名，例如 (jane@example.com)',
    'files'                 => '文件',
    'file_name'				=> '文件',
    'file_type'             => '文件类型',
    'file_uploads'			=> '文件上传',
    'generate'				=> '生成',
     'github_markdown'      => '该字段可以使用 <a href="https://help.github.com/articles/github-flavored-markdown/">Github flavored markdown语法</a>',
    'groups'				=> '分组',
    'gravatar_email'        => 'Gravatar头像邮件地址',
    'history'  			    => '历史记录',
    'history_for'  			=> '历史记录',
    'id'  					=> '编号',
    'image'                 => '图片',
    'image_delete'         	=> '删除图片',
    'image_upload'         	=> '上传图片',
    'image_filetypes_help'  => '接受jpg，png，gif和svg类型的文件。文件大小应小于 :size。',
    'import'         	    => '导入',
    'importing'         	=> '正在导入…',
    'importing_help'        => '您可以通过CSV文件导入资产、配件、许可证、组件、消耗品和用户。 <br><br>CSV 应以逗号分隔和格式化，并且在文档</a> 中与 <a href="https://snipe-it.readme.io/docs/importing" target="_new">样本CSV中的标头匹配。',
    'import-history'        => '导入历史记录',
    'asset_maintenance'        => '资产维修',
    'asset_maintenance_report' => '资产维修报表',
    'asset_maintenances'       => '资产维修',
    'item'  				=> '条目',
    'insufficient_permissions' => '没有足够的权限',
    'kits'       			=> '预定义的 Kits',
    'language'				=> '语言',
    'last'					=> '最后页',
    'last_login'            => '上一次登陆：',
    'last_name'             => '姓氏',
    'license'				=> '授权许可',
    'license_report'        => '授权许可报告',
    'licenses_available'	=> '可用许可',
    'licenses'				=> '许可证',
    'list_all'				=> '列出全部',
    'loading'				=> '加载中',
    'lock_passwords'        => '此字段值将不会保存到演示安装中。',
    'feature_disabled'      => '演示模式下禁用此功能',
    'location'              => '位置',
    'locations'				=> '地理位置',
    'logo_size'				=> '方形标志使用Logo + 文本看起来最好。标志最大显示尺寸为 50px 高 x 500px 宽度。  ',
    'logout'				=> '注销',
    'lookup_by_tag'     => '查找资产标签',
    'maintenances'          => '维护',
    'manufacturer'			=> '制造商',
    'manufacturers'			=> '制造商',
    'markdown'				=> '该字段可以使用 <a href="https://help.github.com/articles/github-flavored-markdown/">Github flavored markdown</a>',
    'min_amt'				=> 'Min. QTY',
    'min_amt_help'	=> '触发告警的最小数量',
    'model_no'				=> '型号',
    'months'				=> '月数',
    'moreinfo'				=> '更多信息',
    'name'					=> '名称',
    'next'					=> '下一页',
    'next_audit_date'		=> '下一次盘点时间',
    'last_audit'		    => '上一次盘点',
    'new'					=> '新！',
    'no_depreciation'		=> '永久',
    'no_results'			=> '没有结果',
    'no'  					=> '否',
    'notes'  				=> '备注',
    'order_number'          => '订单号',
    'page_menu'				=> '显示菜单项',
    'pagination_info'		=> '显示全部',
    'pending'				=> '待定',
    'people'				=> '组织成员',
    'per_page'				=> '每页搜索结果',
    'previous'				=> '前一页',
    'processing'			=> '处理中',
    'profile'				=> '您的个人资料',
    'purchase_cost'                              => '采购价格',
    'purchase_date'         => '购买日期',
    'qty'		            => '数量',
    'quantity'		        => '数量',
    'ready_to_deploy'		=> '待分配',
    'recent_activity'		=> '最近操作活动',
    'remove_company'        => '移除公司关联',
    'reports'				=> '报告',
    'restored'				=> '恢复',
    'requested'				=> '已申请',
    'request_canceled'      => '取消请求',
    'save'  				=> '保存​​',
    'select'				=> '选择',
    'search'				=> '搜索',
    'select_category'       => '选择一个类别',
    'select_department'       => '选择一个部门',
    'select_depreciation'	=> '选择失效类型',
    'select_location'		=> '选择地点',
    'select_manufacturer'	=> '选择生产商',
    'select_model'			=> '选择型号',
    'select_supplier'		=> '选择供货商',
    'select_user'			=> '选择用户',
    'select_date'			=> '选择日期 (YYYY-MM-DD)',
    'select_statuslabel'	=> '选择状态',
    'select_company'    	=> '选择公司',
    'select_asset'    		=> '选择资产',
    'settings'				=> '设置',
    'show_deleted'  		=> '查看已删除',
    'show_current'  		=> '查看当前',
    'sign_in'				=> '登录',
    'signature'             => '签名',
    'skin'       			=> '主题',
    'slack_test_msg'        => '哦哈！看起来 Slack 已经成功应用到 Snipe-IT 了！',
    'some_features_disabled' => '演示模式: 此安装将禁用某些功能。',
    'site_name'				=> '站点名称',
    'state'  				=> '省份',
    'status_labels'			=> '状态标签',
    'status'    			=> '状态',
    'supplier'              => '供应商',
    'suppliers'  			=> '供应商',
    'sure_to_delete'    => '是否确认要删除',
    'submit'				=> '提交',
    'target'                => '目标',
    'time_and_date_display' => '时间和日期显示',
    'total_assets'			=> '共计资产',
    'total_licenses'		=> '共计许可证',
    'total_accessories'		=> '总配件',
    'total_consumables'		=> '总耗材',
    'type'  				=> '类型',
    'undeployable'			=> '无法被分配',
    'unknown_admin'			=> '未知管理员',
    'username_format'		=> '用户名格式',
    'update'                => '更新',
    'upload_filetypes_help'      => '允许的文件类型是 png, gif, jpg, jpeg, doc, doc, pdf, xls, xlsx, txt, lic, xml, zip, rtf 和 rar. 允许的最大上传大小是 :size.',
    'uploaded'              => '已上传',
    'user'					=> '用户',
    'accepted'			    => '已接受',
    'declined'			    => '已拒绝',
    'unaccepted_asset_report' => '未接受的资产',
    'users'                 => '用户',
    'viewall'				=> '查看全部',
    'viewassets'  			=> '查看资产分配',
    'website'               => '站点',
    'welcome'				=> '欢迎您，:name',
    'years'					=> '年',
    'yes' 					=> '是',
    'zip'  					=> 'Zip',
    'noimage'				=> '图片未上传或图片无法找到。',
    'token_expired'         => '表单会话已过期，请重新提交',
    'login_enabled'         => '登录已启用',
    'audit_due'             => '到期审计',
    'audit_overdue'         => '过期审计',
    'accept'                => '接受 :asset',
    'i_accept'              => '我接受',
    'i_decline'             => '我拒绝',
    'sign_tos'              => '请在下面登录以表明您同意服务条款：',
    'clear_signature'       => '清除签名',
    'show_help'             => '显示帮助',
    'hide_help'             => '隐藏帮助',
    ];

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/zh-CN/general.php <==
<?php

    return [
    'accessories'			=> '附属品',
    'activated'			    => '已激活',
    'accessory'				=> '附属品',
    'accessory_report'		=> '配件报告',
    'action'                => '操作',
    'activity_report'		=> '活动报告',
    'address'				=> '地址',
    'admin'					=> '管理员',
    'administrator'			=> '管理员',
    'add_seats'             => '已增加空位',
    'all_assets'			=> '所有资产',
    'all'       			=> '所有',
    'archived'              => '已存档',
    'asset_models'			=> '资产型号',
    'asset_model'			=> '模型',
    'asset'					=> '资产',
    'asset_report'          => '资产报备',
    'asset_tag'				=> '资产标签',
    'asset_tags'            => '资产标签',
    'assets_available'		=> '可用资产',
    'accept_assets'         => '接受资产：名称',
    'accept_assets_menu'    => '接受资产',
    'audit'				    => '审计',
    'audit_report'			=> '审核日志',
    'assets'				=> '资产',
    'avatar_delete'         => '删除头像',
    'avatar_upload'         => '上传头像',
    'back'      			=> '后退',
    'bad_data'      		=> '未发现任何东西，是否数据错误？',
    'bulkaudit'             => '批量审核',
    'bulkaudit_status'      => '盘点状态',
    'bulk_checkout'  		=> '批量借出',
    'bulk_edit'             => '批量编辑',
    'bulk_delete'           => '批量删除',
    'bulk_actions'          => '批量操作',
    'bulk_checkin_delete'   => '批量签入 &amp; 删除',
    'bystatus'              => '按状态',
    'cancel'  				=> '取消',
    'categories'			=> '目录',
    'category'				=> '类别：',
    'change' 		        => '归还/借出',
    'changeemail'  			=> '更改邮箱',
    'changepassword'  		=> '修改密码',
    'checkin'  				=> '归还',
    'checkin_from'  		=> '输入来源',
    'checkout'  			=> '借出',
    'checkouts_count'       => '签出',
    'checkins_count'        => '签入',
    'user_requests_count'   => '请求',
    'city'  				=> '城市',
    'click_here'			=> '点击此处',
    'clear_selection'		=> '清除选择',
    'companies'			    => '公司',
    'company'				=> '公司',
    'component'			    => '组件',
    'components'			=> '组件',
    'complete'				=> '完成',
    'consumable'			=> '消耗品',
    'consumables'			=> '消耗品',
    'country'  				=> '国家',
    'create'				=> '新增',
    'created'               => '项目已创建',
    'created_asset'			=> '新建资产',
    'created_at' 			=> '创建于',
    'record_created' 		=> '记录已创建',
    'updated_at' 			=> '更新日期',
    'currency'  			=> 'RMB', // this is deprecated
    'current'  				=> '当前',
    'current_password'      => '当前密码',
    'customize_report'      => '自定义报告',
    'custom_report'         => '自定义资产报表',
    'dashboard'				=> '控制面板',
    'days'      			=> '天数',
    'days_to_next_audit'    => '距离下一次盘点的天数',
    'date'					=> '日期',
    'debug_warning'         => '警告!',
    'debug_warning_text'    => '此应用程序运行在生产模式下的调试状态。如果您的应用程序可以被外部访问，这会使敏感数据暴露。通过将 <code>.env</code> 文件中的<code>APP_DEBUG</code> 值设置为 <code>false</code>来 禁用调试模式。',
    'delete'  				=> '刪除',
    'delete_confirm'  		=> '是否确定删除此项',
    'deleted'  				=> '已删除',
    'delete_seats'  		=> '已移除空位',
    'deletion_failed'       => '删除失败',
    'departments'           => '部门',
    'department'            => '部门',
    'deployed'				=> '已分配',
    'depreciation'			=> '折旧',
    'depreciations'         => '折旧',
    'depreciation_report'	=> '折旧报告',
    'details'               => '详细信息',
    'download'				=> '下载',
    'download_all'		    => '下载全部',
    'editprofile'  			=> '修改简介',
    'eol'					=> '寿命',
    'email_domain'			=> '邮件域',
    'email_format'			=> '电子邮件格式',
    'employee_number'       => '员工号码',
    'email_domain_help'		=> '这在导入时用以生成电子邮件地址',
    'error'				    => '错误',
    'filastname_format'			=> '缩写名 姓，例如(jsmith@example.com)',
    'firstname_lastname_format'	=> '名 姓，例如 (jane.smith@example.com)',
    'firstname_lastname_underscore_format' => '名 姓，例如(jane_smith@example.com)',
    'lastnamefirstinitial_format' =>  '姓氏首字母（smithj@example.com）',
    'firstintial_dot_lastname_format' => '缩写名 姓，例如(jsmith@example.com)',
    'first'					=> '首页',
    'firstnamelastname'     => '名 姓，例如 (jane.smith@example.com)',
    'lastname_firstinitial' => '姓 缩写名, 例如 (smith_j@example.com)',
    'firstinitial.lastname' => '缩写名 姓，例如(jsmith@example.com)',
    'firstnamelastinitial'  => '名 姓，例如 (jane.smith@example.com)',
    'first_name'			=> '名字',
    'first_name_format'		=> '名，例如 (jane@example.com)',
    'files'                 => '文件',
    'file_name'				=> '文件',
    'file_type'             => '文件类型',
    'file_uploads'			=> '文件上传',
    'file_upload'           => '文件上传',
    'generate'				=> '生成',
    'generate_labels'       => '生成标签',
    'github_markdown'      => '该字段可以使用 <a href="https://help.github.com/articles/github-flavored-markdown/">Github flavored markdown语法</a>',
    'groups'				=> '分组',
    'gravatar_email'        => 'Gravatar头像邮件地址',
    'gravatar_url'          => '<a href="http://gravatar.com"><small>在 Gravatar.com</small></a> 更改您的头像。',
    'history'  			    => '历史记录',
    'history_for'  			=> '历史记录',
    'id'  					=> '编号',
    'image'                 => '图片',
    'image_delete'         	=> '删除图片',
    'image_upload'         	=> '上传图片',
    'filetypes_accepted_help'    => '可接受的文件类型是 :types. 最大允许上传大小为 :size.|可接受的文件类型是 :types. 最大允许上传大小为 :size.',
    'filetypes_size_help'   => '允许最大上传文件的大小为 :size.',
    'image_filetypes_help'  => '接受jpg，png，gif和svg类型的文件。文件大小应小于 :size。',
    'import'         	    => '导入',
    'importing'         	=> '正在导入…',
    'importing_help'        => '您可以通过CSV文件导入资产、配件、许可证、组件、消耗品和用户。 <br><br>CSV 应以逗号分隔和格式化，并且在文档</a> 中与 <a href="https://snipe-it.readme.io/docs/importing" target="_new">样本CSV中的标头匹配。',
    'import-history'        => '导入历史记录',
    'asset_maintenance'        => '资产维修',
    'asset_maintenance_report' => '资产维修报表',
    'asset_maintenances'       => '资产维修',
    'item'  				=> '条目',
    'item_name'             => '物品名称',
    'insufficient_permissions' => '没有足够的权限',
    'kits'       			=> '预定义的 Kits',
    'language'				=> '语言',
    'last'					=> '最后页',
    'last_login'            => '上一次登陆：',
    'last_name'             => '姓氏',
    'license'				=> '授权许可',
    'license_report'        => '授权许可报告',
    'licenses_available'	=> '可用许可',
    'licenses'				=> '许可证',
    'list_all'				=> '列出全部',
    'loading'				=> '正在加载... 请稍候...',
    'lock_passwords'        => '此字段值将不会保存到演示安装中。',
    'feature_disabled'      => '演示模式下禁用此功能',
    'location'              => '位置',
    'locations'				=> '地理位置',
    'logo_size'				=> '方形标志使用Logo + 文本看起来最好。标志最大显示尺寸为 50px 高 x 500px 宽度。  ',
    'logout'				=> '注销',
    'lookup_by_tag'     => '查找资产标签',
    'maintenances'          => '维护',
    'manage_api_keys'       => '管理 API 密钥',
    'manufacturer'			=> '制造商',
    'manufacturers'			=> '制造商',
    'markdown'				=> '该字段可以使用 <a href="https://help.github.com/articles/github-flavored-markdown/">Github flavored markdown</a>',
    'min_amt'				=> 'Min. QTY',
    'min_amt_help'          => '在触发警报之前应该可用的最小物品数。如果您不希望收到低库存的警报，请将最小数量留空。',
    'model_no'				=> '型号',
    'months'				=> '月数',
    'moreinfo'				=> '更多信息',
    'name'					=> '名称',
    'new_password'          => '新密码',
    'next'					=> '下一页',
    'next_audit_date'		=> '下一次盘点时间',
    'last_audit'		    => '上一次盘点',
    'new'					=> '新！',
    'no_depreciation'		=> '永久',
    'no_results'			=> '没有结果',
    'no'  					=> '否',
    'notes'  				=> '备注',
    'order_number'          => '订单号',
    'page_menu'				=> '显示菜单项',
    'pagination_info'		=> '显示全部',
    'pending'				=> '待定',
    'people'				=> '组织成员',
    'per_page'				=> '每页搜索结果',
    'previous'				=> '前一页',
    'processing'			=> '处理中',
    'profile'				=> '您的个人资料',
    'purchase_cost'                              => '采购价格',
    'purchase_date'         => '购买日期',
    'qty'		            => '数量',
    'quantity'		        => '数量',
    'quantity_minimum'      => '您有 :count 物品低于或几乎低于最低数量级别',
    'quickscan_checkin'  	=> '快速扫描归还',
    'quickscan_checkin_status'  	=> '归还状态',
    'ready_to_deploy'		=> '待分配',
    'recent_activity'		=> '最近操作活动',
    'remaining'             => '剩余',
    'remove_company'        => '移除公司关联',
    'reports'				=> '报告',
    'restored'				=> '恢复',
    'restore'				=> '还原',
    'requestable_models'    => '可申领的型号',
    'requested'				=> '已申请',
    'requested_date'        => '申领日期',
    'requested_assets'      => '已申领资产',
    'requested_assets_menu' => '已申领资产',
    'request_canceled'      => '取消请求',
    'save'  				=> '保存​​',
    'select'				=> '选择',
    'select_all'            => '全选',
    'search'				=> '搜索',
    'select_category'       => '选择一个类别',
    'select_department'     => '选择一个部门',
    'select_depreciation'	=> '选择失效类型',
    'select_location'		=> '选择地点',
    'select_manufacturer'	=> '选择生产商',
    'select_model'			=> '选择型号',
    'select_supplier'		=> '选择供货商',
    'select_user'			=> '选择用户',
    'select_date'			=> '选择日期 (YYYY-MM-DD)',
    'select_statuslabel'	=> '选择状态',
    'select_company'    	=> '选择公司',
    'select_asset'    		=> '选择资产',
    'settings'				=> '设置',
    'show_deleted'  		=> '查看已删除',
    'show_current'  		=> '查看当前',
    'sign_in'				=> '登录',
    'signature'             => '签名',
    'skin'       			=> '主题',
    'slack_msg_note'        => '将发送一条slack消息',
    'slack_test_msg'        => '哦哈！看起来 Slack 已经成功应用到 Snipe-IT 了！',
    'some_features_disabled' => '演示模式: 此安装将禁用某些功能。',
    'site_name'				=> '站点名称',
    'state'  				=> '省份',
    'status_labels'			=> '状态标签',
    'status'    			=> '状态',
    'supplier'              => '供应商',
    'suppliers'  			=> '供应商',
    'sure_to_delete'    => '是否确认要删除',
    'submit'				=> '提交',
    'target'                => '目标',
    'toggle_navigation'     => 'Toogle 导航',
    'time_and_date_display' => '时间和日期显示',
    'total_assets'			=> '共计资产',
    'total_licenses'		=> '共计许可证',
    'total_accessories'		=> '总配件',
    'total_consumables'		=> '总耗材',
    'type'  				=> '类型',
    'undeployable'			=> '无法被分配',
    'unknown_admin'			=> '未知管理员',
    'username_format'		=> '用户名格式',
    'update'                => '更新',
    'upload_filetypes_help'      => '允许的文件类型是 png, gif, jpg, jpeg, doc, doc, pdf, xls, xlsx, txt, lic, xml, zip, rtf 和 rar. 允许的最大上传大小是 :size.',
    'uploaded'              => '已上传',
    'user'					=> '用户',
    'accepted'			    => '已接受',
    'declined'			    => '已拒绝',
    'unaccepted_asset_report' => '未接受的资产',
    'users'                 => '用户',
    'viewall'				=> '查看全部',
    'viewassets'  			=> '查看资产分配',
    'viewassetsfor'         => '查看资产 :name',
    'website'               => '站点',
    'welcome'				=> '欢迎您，:name',
    'years'					=> '年',
    'yes' 					=> '是',
    'zip'  					=> 'Zip',
    'noimage'				=> '图片未上传或图片无法找到。',
    'token_expired'         => '表单会话已过期，请重新提交',
    'login_enabled'         => '登录已启用',
    'audit_due'             => '到期审计',
    'audit_overdue'         => '过期审计',
    'accept'                => '接受 :asset',
    'i_accept'              => '我接受',
    'i_decline'             => '我拒绝',
    'accept_decline'        => '接受/拒绝',
    'sign_tos'              => '请在下面登录以表明您同意服务条款：',
    'clear_signature'       => '清除签名',
    'show_help'             => '显示帮助',
    'hide_help'             => '隐藏帮助',
    'view_all'              => '查看全部',
    'hide_deleted'          => '隐藏已删除',
    'email'                 => '邮箱',
    'do_not_change'         => '不要更改',
    'bug_report'            => '报告错误',
    'user_manual'           => '用户手册',
    'setup_step_1'          => '第 1 步',
    'setup_step_2'          => '第 2 步',
    'setup_step_3'          => '第 3 步',
    'setup_step_4'          => '第 4 步',
    'setup_config_check'    => '配置检查',
    'setup_create_database' => '创建数据库表',
    'setup_create_admin'    => '创建管理员用户',
    'setup_done'            => '完成！',
    'bulk_edit_about_to'    => '您将要编辑以下内容： ',
    'checked_out'           => '已借出',
    'checked_out_to'        => '借出至',
    'fields'                => '字段',
    'last_checkout'         => '上次借出',
    'due_to_checkin'        => '以下:count 物品将很快归还：',
    'expected_checkin'      => '预计归还日期',
    'reminder_checked_out_items' => '这是当前借出给您的物品的提醒。 如果你觉得这个列表不准确(有些东西缺失，或者你认为你从未收到的东西)，请发送电子邮件::reply_to_name 到 :reply_to_address_address。',
    'changed'               => '已修改',
    'to'                    => '至',
    'report_fields_info'    => '<p>选择您想要在自定义报告中包含的字段，然后单击生成. 该文件 (cunstom-YYYY-mm-dd.csv) 将自动下载，您可以在 Excel中打开它。</p>
            <p>如果您只想导出某些资产，使用下面的选项来微调您的结果。</p>',
    'range'                 => '范围',
    'bom_remark'            => '向这个CSV文件添加一个BOM(字节顺序标记)',
    'improvements'          => '改进',
    'information'           => '信息',
    'permissions'           => '权限',
    'managed_ldap'          => '(通过 LDAP 管理)',
    'export'                => '导出',
    'ldap_sync'             => 'LDAP 同步',
    'ldap_user_sync'        => 'LDAP 用户同步',
    'synchronize'           => '同步',
    'sync_results'          => '同步结果',
    'license_serial'        => '序列号/产品密钥',
    'invalid_category'      => '无效的类别',
    'dashboard_info'        => '这是您的仪表板。有很多类似的，但这个就是您的。',
    '60_percent_warning'    => '60% 完成 (警告)',
    'dashboard_empty'       => '看起来你还没有添加任何东西，所以我们没有什么东西可以显示。 现在就开始添加一些资产、配件、耗材或许可证吧！',
    'new_asset'             => '新建资产',
    'new_license'           => '新建许可证',
    'new_accessory'         => '新建配件',
    'new_consumable'        => '新建耗材',
    'collapse'              => '收起',
    'assigned'              => '已分配',
    'asset_count'           => '资产计数',
    'accessories_count'     => '配件计数',
    'consumables_count'     => '耗材计数',
    'components_count'      => '组件计数',
    'licenses_count'        => '许可证计数',
    'notification_error'    => '错误：',
    'notification_error_hint' => '请检查下面的表单以了解错误',
    'notification_success'  => '成功：',
    'notification_warning'   => '警告：',
    'notification_info'      => '信息：',
    'asset_information'     => '资产信息',
    'model_name'            => '型号名称：',
    'asset_name'            => '资产名称：',
    'consumable_information' => '耗材信息:',
    'consumable_name'       => '耗材名称:',
    'accessory_information' => '配件信息：',
    'accessory_name'       => '配件名称:',
    'clone_item'            => '克隆物品',
    'checkout_tooltip' => '借出此物品',
    'checkin_tooltip' => '归还此物品',
    'checkout_user_tooltip' => '借出此物品给一个用户',
];
